/// <reference types="node" />
import type { IncomingMessage, ServerResponse, Server as HTTPServer, RequestListener } from 'http';
export interface TokenMetadata {
    client_id: string;
    scope: string;
    nonce?: string;
}
export type MaybePromise<T> = T | PromiseLike<T>;
export interface OIDCMockProviderConfig {
    getTokenPayload(metadata: TokenMetadata): MaybePromise<{
        expires_in: number;
        payload: Record<string, unknown>;
        customIdTokenPayload?: Record<string, unknown>;
        skipIdToken?: boolean;
    }>;
    overrideRequestHandler?(url: string, req: IncomingMessage, res: ServerResponse): MaybePromise<void>;
    port?: number;
    hostname?: string;
    bindIpAll?: boolean;
    additionalIssuerMetadata?: () => Record<string, unknown>;
    createHTTPServer?: (requestListener: RequestListener) => HTTPServer;
}
export declare class OIDCMockProvider {
    httpServer: HTTPServer;
    issuer: string;
    private kid;
    private keys;
    private state;
    private config;
    private constructor();
    private init;
    static create(config: OIDCMockProviderConfig): Promise<OIDCMockProvider>;
    close(): Promise<void>;
    private handleRequest;
    private issueToken;
    private storeForSingleRetrieval;
    private retrieveFromStorage;
}
//# sourceMappingURL=index.d.ts.map